@@ -1,4 +1,3 @@
-
 #   IGraph R package
 #   Copyright (C) 2005-2012  Gabor Csardi <csardi.gabor@gmail.com>
 #   334 Harvard street, Cambridge, MA 02139 USA
@@ -66,7 +65,43 @@ write.graph.fromraw <- function(buffer, file) {
   invisible(NULL)
 }
 
-read.graph <- function(file, format=c("edgelist", "pajek", "ncol", "lgl",
+
+
+#' Reading foreign file formats
+#' 
+#' The \code{read_graph} function is able to read graphs in various
+#' representations from a file, or from a http connection. Currently some
+#' simple formats are supported.
+#' 
+#' The \code{read_graph} function may have additional arguments depending on
+#' the file format (the \code{format} argument). See the details separately for
+#' each file format, below.
+#' 
+#' @aliases read.graph LGL Pajek GraphML GML DL UCINET
+#' @param file The connection to read from. This can be a local file, or a
+#' \code{http} or \code{ftp} connection. It can also be a character string with
+#' the file name or URI.
+#' @param format Character constant giving the file format. Right now
+#' \code{as_edgelist}, \code{pajek}, \code{graphml}, \code{gml}, \code{ncol},
+#' \code{lgl}, \code{dimacs} and \code{graphdb} are supported, the default is
+#' \code{edgelist}. As of igraph 0.4 this argument is case insensitive.
+#' @param \dots Additional arguments, see below.
+#' @return A graph object.
+#' @section Edge list format: This format is a simple text file with numeric
+#' vertex ids defining the edges. There is no need to have newline characters
+#' between the edges, a simple space will also do.
+#' 
+#' Additional arguments: \describe{ \item{n}{The number of vertices in the
+#' graph. If it is smaller than or equal to the largest integer in the file,
+#' then it is ignored; so it is safe to set it to zero (the default).}
+#' \item{directed}{Logical scalar, whether to create a directed graph. The
+#' default value is \code{TRUE}.} }
+#' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
+#' @seealso \code{\link{write_graph}}
+#' @keywords graphs
+#' @export
+
+read_graph <- function(file, format=c("edgelist", "pajek", "ncol", "lgl",
                                "graphml", "dimacs", "graphdb", "gml", "dl"),
                        ...) {
 
@@ -93,10 +128,43 @@ read.graph <- function(file, format=c("edgelist", "pajek", "ncol", "lgl",
   res
 }
 
-write.graph <- function(graph, file, format=c("edgelist", "pajek", "ncol", "lgl",
+
+
+#' Writing the graph to a file in some format
+#' 
+#' \code{write_graph} is a general function for exporting graphs to foreign
+#' file formats, however not many formats are implemented right now.
+#' 
+#' @aliases write.graph
+#' @param graph The graph to export.
+#' @param file A connection or a string giving the file name to write the graph
+#' to.
+#' @param format Character string giving the file format. Right now
+#' \code{pajek}, \code{graphml}, \code{dot}, \code{gml}, \code{edgelist},
+#' \code{lgl}, \code{ncol} and \code{dimacs} are implemented. As of igraph 0.4
+#' this argument is case insensitive.
+#' @param \dots Other, format specific arguments, see below.
+#' @return A NULL, invisibly.
+#' @section Edge list format: The \code{edgelist} format is a simple text file,
+#' with one edge in a line, the two vertex ids separated by a space character.
+#' The file is sorted by the first and the second column. This format has no
+#' additional arguments.
+#' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
+#' @seealso \code{\link{read_graph}}
+#' @references Adai AT, Date SV, Wieland S, Marcotte EM. LGL: creating a map of
+#' protein function with an algorithm for visualizing very large biological
+#' networks. \emph{J Mol Biol.} 2004 Jun 25;340(1):179-90.
+#' @export
+#' @keywords graphs
+#' @examples
+#' 
+#' g <- make_ring(10)
+#' \dontrun{write_graph(g, "/tmp/g.txt", "edgelist")}
+#' 
+write_graph <- function(graph, file, format=c("edgelist", "pajek", "ncol", "lgl",
                                        "graphml", "dimacs", "gml", "dot", "leda"), ...) {
 
-  if (!is.igraph(graph)) {
+  if (!is_igraph(graph)) {
     stop("Not a graph object")
   }
   if (!is.character(file) || length(grep("://", file, fixed=TRUE)) > 0 ||
@@ -138,7 +206,7 @@ read.graph.edgelist <- function(file, n=0,
                                 directed=TRUE, ...) {
 
   if (length(list(...))>0) {
-    stop("Unknown arguments to read.graph (edgelist format)")
+    stop("Unknown arguments to read_graph (edgelist format)")
   }
   on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
   .Call("R_igraph_read_graph_edgelist", file,
@@ -149,7 +217,7 @@ read.graph.edgelist <- function(file, n=0,
 write.graph.edgelist <- function(graph, file, ...) {
   
   if (length(list(...))>0) {
-    stop("Unknown arguments to write.graph (edgelist format)")
+    stop("Unknown arguments to write_graph (edgelist format)")
   }
   on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
   .Call("R_igraph_write_graph_edgelist", graph, file,
@@ -165,7 +233,7 @@ read.graph.ncol <- function(file, predef=character(0), names=TRUE,
                             directed=FALSE, ...) {
 
   if (length(list(...))>0) {
-    stop("Unknown arguments to read.graph (NCOL format)")
+    stop("Unknown arguments to read_graph (NCOL format)")
   }
   weights <- switch(igraph.match.arg(weights), "no"=0, "yes"=1, "auto"=2)
   on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
@@ -177,12 +245,12 @@ read.graph.ncol <- function(file, predef=character(0), names=TRUE,
 write.graph.ncol <- function(graph, file, 
                              names="name", weights="weight", ...) {
   if (length(list(...))>0) {
-    stop("Unknown arguments to write.graph (NCOL format)")
+    stop("Unknown arguments to write_graph (NCOL format)")
   }
   names <- as.character(names)
   weights <- as.character(weights)
-  if (length(names)==0 || ! names %in% list.vertex.attributes(graph)) { names <- NULL }
-  if (length(weights)==0 || ! weights %in% list.edge.attributes(graph)) { weights <- NULL }
+  if (length(names)==0 || ! names %in% vertex_attr_names(graph)) { names <- NULL }
+  if (length(weights)==0 || ! weights %in% edge_attr_names(graph)) { weights <- NULL }
   
   on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
   .Call("R_igraph_write_graph_ncol", graph, file,
@@ -196,7 +264,7 @@ read.graph.lgl <- function(file, names=TRUE,
                             ...) {
 
   if (length(list(...))>0) {
-    stop("Unknown arguments to read.graph (LGL format)")
+    stop("Unknown arguments to read_graph (LGL format)")
   }
   weights <- switch(igraph.match.arg(weights), "no"=0, "yes"=1, "auto"=2)
   on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
@@ -209,12 +277,12 @@ write.graph.lgl <- function(graph, file,
                             names="name", weights="weight",
                             isolates=FALSE, ...) {
   if (length(list(...))>0) {
-    stop("Unknown arguments to write.graph (LGL format)")
+    stop("Unknown arguments to write_graph (LGL format)")
   }
   names <- as.character(names)
   weights <- as.character(weights)
-  if (length(names)==0 || ! names %in% list.vertex.attributes(graph)) { names <- NULL }
-  if (length(weights)==0 || ! weights %in% list.edge.attributes(graph)) { weights <- NULL }
+  if (length(names)==0 || ! names %in% vertex_attr_names(graph)) { names <- NULL }
+  if (length(weights)==0 || ! weights %in% edge_attr_names(graph)) { weights <- NULL }
   
   on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
   .Call("R_igraph_write_graph_lgl", graph, file,
@@ -225,15 +293,15 @@ write.graph.lgl <- function(graph, file,
 read.graph.pajek <- function(file, ...) {
 
   if (length(list(...))>0) {
-    stop("Unknown arguments to read.graph (Pajek format)")
+    stop("Unknown arguments to read_graph (Pajek format)")
   }
   on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
   res <- .Call("R_igraph_read_graph_pajek", file,
                PACKAGE="igraph")
-  if ("type" %in% list.vertex.attributes(res)) {
+  if ("type" %in% vertex_attr_names(res)) {
     type <- as.logical(V(res)$type)
-    res <- remove.vertex.attribute(res, "type")
-    res <- set.vertex.attribute(res, "type", value=type)
+    res <- delete_vertex_attr(res, "type")
+    res <- set_vertex_attr(res, "type", value=type)
   }
   res
 }
@@ -241,7 +309,7 @@ read.graph.pajek <- function(file, ...) {
 write.graph.pajek <- function(graph, file, ...) {
 
   if (length(list(...))>0) {
-    stop("Unknown arguments to write.graph (Pajek format)")
+    stop("Unknown arguments to write_graph (Pajek format)")
   }
   on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
   .Call("R_igraph_write_graph_pajek", graph, file,
@@ -251,20 +319,20 @@ write.graph.pajek <- function(graph, file, ...) {
 read.graph.dimacs <- function(file, directed=TRUE, ...) {
 
   if (length(list(...))>0) {
-    stop("Unknown arguments to read.graph (DIMACS format)")
+    stop("Unknown arguments to read_graph (DIMACS format)")
   }
   res <- .Call("R_igraph_read_graph_dimacs", file, as.logical(directed),
                PACKAGE="igraph")
   if (res[[1]][1] == "max") {
     graph <- res[[2]]
-    graph <- set.graph.attribute(graph, "problem", res[[1]])
-    graph <- set.graph.attribute(graph, "source", res[[3]])
-    graph <- set.graph.attribute(graph, "target", res[[4]])
+    graph <- set_graph_attr(graph, "problem", res[[1]])
+    graph <- set_graph_attr(graph, "source", res[[3]])
+    graph <- set_graph_attr(graph, "target", res[[4]])
     E(graph)$capacity <- res[[5]]
     graph
   } else if (res[[1]][1] == "edge") {
     graph <- res[[2]]
-    graph <- set.graph.attribute(graph, "problem", res[[1]])
+    graph <- set_graph_attr(graph, "problem", res[[1]])
     V(graph)$label <- res[[3]]
     graph
   }
@@ -274,13 +342,13 @@ write.graph.dimacs <- function(graph, file,
                                source=NULL, target=NULL, capacity=NULL, ...) {
 
   if (length(list(...))>0) {
-    stop("Unknown arguments to write.graph (DIMACS format)")
+    stop("Unknown arguments to write_graph (DIMACS format)")
   }
   if (is.null(source)) {
-    source <- get.graph.attribute(graph, "source")
+    source <- graph_attr(graph, "source")
   }
   if (is.null(target)) {
-    target <- get.graph.attribute(graph, "target")
+    target <- graph_attr(graph, "target")
   }
   if (is.null(capacity)) {
     capacity <- E(graph)$capacity
@@ -299,20 +367,20 @@ write.graph.dimacs <- function(graph, file,
 read.graph.graphml <- function(file, index=0, ...) {
 
   if (length(list(...))>0) {
-    stop("Unknown arguments to read.graph (GraphML format)")
+    stop("Unknown arguments to read_graph (GraphML format)")
   }
   on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
   .Call("R_igraph_read_graph_graphml", file, as.numeric(index),
         PACKAGE="igraph")
 }
 
-write.graph.graphml <- function(graph, file, ...) {
+write.graph.graphml <- function(graph, file, prefixAttr=TRUE, ...) {
 
   if (length(list(...))>0) {
-    stop("Unknown arguments to write.graph (GraphML format)")
+    stop("Unknown arguments to write_graph (GraphML format)")
   }
   on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  .Call("R_igraph_write_graph_graphml", graph, file,
+  .Call("R_igraph_write_graph_graphml", graph, file, as.logical(prefixAttr),
         PACKAGE="igraph")
 }
 
@@ -322,7 +390,7 @@ write.graph.graphml <- function(graph, file, ...) {
 
 read.graph.gml <- function(file, ...) {
   if (length(list(...))>0) {
-    stop("Unknown arguments to read.graph (GML format)")
+    stop("Unknown arguments to read_graph (GML format)")
   }
   on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
   .Call("R_igraph_read_graph_gml", file,
@@ -331,7 +399,7 @@ read.graph.gml <- function(file, ...) {
 
 write.graph.gml <- function(graph, file, id=NULL, creator=NULL, ...) {
   if (length(list(...))>0) {
-    stop("Unknown arguments to write.graph (GML format)")
+    stop("Unknown arguments to write_graph (GML format)")
   }
   if (!is.null(id)) {
     id <- as.numeric(id)
@@ -350,7 +418,7 @@ write.graph.gml <- function(graph, file, id=NULL, creator=NULL, ...) {
 
 read.graph.dl <- function(file, directed=TRUE, ...) {
   if (length(list(...))>0) {
-    stop("Unknown arguments to read.graph (DL format)")
+    stop("Unknown arguments to read_graph (DL format)")
   }
   on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
   .Call("R_igraph_read_graph_dl", file, as.logical(directed),
@@ -363,7 +431,7 @@ read.graph.dl <- function(file, directed=TRUE, ...) {
 
 write.graph.dot <- function(graph, file, ...) {
   if (length(list(...))>0) {
-    stop("Unknown arguments to write.graph (DOT format)")
+    stop("Unknown arguments to write_graph (DOT format)")
   }
   on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
   .Call("R_igraph_write_graph_dot", graph, file,
@@ -375,7 +443,73 @@ write.graph.dot <- function(graph, file, ...) {
 # isomorphic problems
 ################################################################
 
-graph.graphdb <- function(url=NULL,
+
+
+#' Load a graph from the graph database for testing graph isomorphism.
+#' 
+#' This function downloads a graph from a database created for the evaluation
+#' of graph isomorphism testing algothitms.
+#' 
+#' \code{graph_from_graphdb} reads a graph from the graph database from an FTP or
+#' HTTP server or from a local copy. It has two modes of operation:
+#' 
+#' If the \code{url} argument is specified then it should the complete path to
+#' a local or remote graph database file. In this case we simply call
+#' \code{\link{read_graph}} with the proper arguments to read the file.
+#' 
+#' If \code{url} is \code{NULL}, and this is the default, then the filename is
+#' assembled from the \code{base}, \code{prefix}, \code{type}, \code{nodes},
+#' \code{pair} and \code{which} arguments.
+#' 
+#' Unfortunately the original graph database homepage is now defunct, but see
+#' its old version at
+#' \url{http://web.archive.org/web/20090215182331/http://amalfi.dis.unina.it/graph/db/doc/graphdbat.html}
+#' for the actual format of a graph database file and other information.
+#'
+#' @aliases graph.graphdb
+#' @param url If not \code{NULL} it is a complete URL with the file to import.
+#' @param prefix Gives the prefix. See details below. Possible values:
+#' \code{iso}, \code{i2}, \code{si4}, \code{si6}, \code{mcs10}, \code{mcs30},
+#' \code{mcs50}, \code{mcs70}, \code{mcs90}.
+#' @param type Gives the graph type identifier. See details below. Possible
+#' values: \code{r001}, \code{r005}, \code{r01}, \code{r02}, \code{m2D},
+#' \code{m2Dr2}, \code{m2Dr4}, \code{m2Dr6} \code{m3D}, \code{m3Dr2},
+#' \code{m3Dr4}, \code{m3Dr6}, \code{m4D}, \code{m4Dr2}, \code{m4Dr4},
+#' \code{m4Dr6}, \code{b03}, \code{b03m}, \code{b06}, \code{b06m}, \code{b09},
+#' \code{b09m}.
+#' @param nodes The number of vertices in the graph.
+#' @param pair Specifies which graph of the pair to read. Possible values:
+#' \code{A} and \code{B}.
+#' @param which Gives the number of the graph to read. For every graph type
+#' there are a number of actual graphs in the database. This argument specifies
+#' which one to read.
+#' @param base The base address of the database. See details below.
+#' @param compressed Logical constant, if TRUE than the file is expected to be
+#' compressed by gzip. If \code{url} is \code{NULL} then a \sQuote{\code{.gz}}
+#' suffix is added to the filename.
+#' @param directed Logical constant, whether to create a directed graph.
+#' @return A new graph object.
+#' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
+#' @seealso \code{\link{read_graph}}, \code{\link{graph.isomorphic.vf2}}
+#' @references M. De Santo, P. Foggia, C. Sansone, M. Vento: A large database
+#' of graphs and its use for benchmarking graph isomorphism algorithms,
+#' \emph{Pattern Recognition Letters}, Volume 24, Issue 8 (May 2003)
+#' @export
+#' @keywords graphs
+#' @examples
+#' 
+#' \dontrun{
+#' g <- graph_from_graphdb(prefix="iso", type="r001", nodes=20, pair="A",
+#'   which=10, compressed=TRUE)
+#' g2 <- graph_from_graphdb(prefix="iso", type="r001", nodes=20, pair="B",
+#'   which=10, compressed=TRUE)
+#' graph.isomorphic.vf2(g, g2)	% should be TRUE
+#' g3 <- graph_from_graphdb(url=paste(sep="/",
+#'                               "http://cneurocvs.rmki.kfki.hu",
+#'                               "graphdb/gzip/iso/bvg/b06m",
+#'                               "iso_b06m_m200.A09.gz"))
+#' }
+graph_from_graphdb <- function(url=NULL,
                           prefix="iso", type="r001", nodes=NULL, pair="A", which=0,
                           base="http://cneurocvs.rmki.kfki.hu/graphdb/gzip",
                           compressed=TRUE, directed=TRUE) {
@@ -430,7 +564,7 @@ graph.graphdb <- function(url=NULL,
 
 read.graph.graphdb <- function(file, directed=TRUE, ...) {
   if (length(list(...))>0) {
-    stop("Unknown arguments to read.graph (GraphDB format)")
+    stop("Unknown arguments to read_graph (GraphDB format)")
   }
   on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
   .Call("R_igraph_read_graph_graphdb", file, as.logical(directed),
@@ -440,7 +574,7 @@ read.graph.graphdb <- function(file, directed=TRUE, ...) {
 write.graph.leda <- function(graph, file, vertex.attr=NULL, edge.attr=NULL,
                              ...) {
   if (length(list(...))>0) {
-    stop("Unknown arguments to write.graph (LEDA format)")
+    stop("Unknown arguments to write_graph (LEDA format)")
   }
   if (!is.null(vertex.attr)) { vertex.attr <- as.character(vertex.attr) }
   if (!is.null(edge.attr))   { edge.attr   <- as.character(edge.attr)   }
