@@ -1,6 +1,5 @@
-/* -*- mode: C -*-  */
 /*
-   IGraph library.
+   igraph library.
    Copyright (C) 2006-2012  Gabor Csardi <csardi.gabor@gmail.com>
    334 Harvard st, Cambridge MA, 02139 USA
 
@@ -23,11 +22,14 @@
 
 #include <igraph.h>
 
-int main() {
+int main(void) {
 
     igraph_vector_int_t v;
     igraph_t g;
 
+    /* Initialize the library. */
+    igraph_setup();
+
     igraph_vector_int_init_int(&v, 2, 5, 5);
     igraph_square_lattice(&g, &v, 1, IGRAPH_DIRECTED, 1 /*mutual*/, 0 /*periodic*/);
     igraph_to_undirected(&g, IGRAPH_TO_UNDIRECTED_COLLAPSE,
