@@ -94,28 +94,38 @@
 
 int igraph_adjlist_init(const igraph_t *graph, igraph_adjlist_t *al, 
 			  igraph_neimode_t mode) {
-  long int i;
+  igraph_integer_t i;
+  igraph_vector_t tmp;  
 
   if (mode != IGRAPH_IN && mode != IGRAPH_OUT && mode != IGRAPH_ALL) {
     IGRAPH_ERROR("Cannot create adjlist view", IGRAPH_EINVMODE);
   }
 
+  igraph_vector_init(&tmp, 0);
+  IGRAPH_FINALLY(igraph_vector_destroy, &tmp);
+
   if (!igraph_is_directed(graph)) { mode=IGRAPH_ALL; }
 
   al->length=igraph_vcount(graph);
-  al->adjs=igraph_Calloc(al->length, igraph_vector_t);
+  al->adjs=igraph_Calloc(al->length, igraph_vector_int_t);
   if (al->adjs == 0) {
     IGRAPH_ERROR("Cannot create adjlist view", IGRAPH_ENOMEM);
   }
 
   IGRAPH_FINALLY(igraph_adjlist_destroy, al);
   for (i=0; i<al->length; i++) {
+    int j, n;
     IGRAPH_ALLOW_INTERRUPTION();
-    IGRAPH_CHECK(igraph_vector_init(&al->adjs[i], 0));
-    IGRAPH_CHECK(igraph_neighbors(graph, &al->adjs[i], i, mode));
+    IGRAPH_CHECK(igraph_neighbors(graph, &tmp, i, mode));
+    n=igraph_vector_size(&tmp);
+    IGRAPH_CHECK(igraph_vector_int_init(&al->adjs[i], n));
+    for (j=0; j<n; j++) {
+      VECTOR(al->adjs[i])[j] = VECTOR(tmp)[j];
+    }
   }
 
-  IGRAPH_FINALLY_CLEAN(1);
+  igraph_vector_destroy(&tmp);
+  IGRAPH_FINALLY_CLEAN(2);
   return 0;
 }
 
@@ -137,14 +147,14 @@ int igraph_adjlist_init_empty(igraph_adjlist_t *al, igraph_integer_t no_of_nodes
   long int i;
 
   al->length=no_of_nodes;
-  al->adjs=igraph_Calloc(al->length, igraph_vector_t);
+  al->adjs=igraph_Calloc(al->length, igraph_vector_int_t);
   if (al->adjs == 0) {
     IGRAPH_ERROR("Cannot create adjlist view", IGRAPH_ENOMEM);
   }
 
   IGRAPH_FINALLY(igraph_adjlist_destroy, al);
   for (i=0; i<al->length; i++) {
-    IGRAPH_CHECK(igraph_vector_init(&al->adjs[i], 0));
+    IGRAPH_CHECK(igraph_vector_int_init(&al->adjs[i], 0));
   }
   IGRAPH_FINALLY_CLEAN(1);
 
@@ -176,7 +186,7 @@ int igraph_adjlist_init_complementer(const igraph_t *graph,
 				       igraph_adjlist_t *al, 
 				       igraph_neimode_t mode,
 				       igraph_bool_t loops) {
-  long int i, j, k, n;
+  igraph_integer_t i, j, k, n;
   igraph_bool_t* seen;
   igraph_vector_t vec;
 
@@ -187,7 +197,7 @@ int igraph_adjlist_init_complementer(const igraph_t *graph,
   if (!igraph_is_directed(graph)) { mode=IGRAPH_ALL; }
 
   al->length=igraph_vcount(graph);
-  al->adjs=igraph_Calloc(al->length, igraph_vector_t);
+  al->adjs=igraph_Calloc(al->length, igraph_vector_int_t);
   if (al->adjs == 0) {
     IGRAPH_ERROR("Cannot create complementer adjlist view", IGRAPH_ENOMEM);
   }
@@ -206,7 +216,7 @@ int igraph_adjlist_init_complementer(const igraph_t *graph,
   for (i=0; i<al->length; i++) {
     IGRAPH_ALLOW_INTERRUPTION();
     igraph_neighbors(graph, &vec, i, mode);
-    memset(seen, 0, sizeof(igraph_bool_t)*al->length);
+    memset(seen, 0, sizeof(igraph_bool_t)*(unsigned) al->length);
     n=al->length;
     if (!loops) { seen[i] = 1; n--; }
     for (j=0; j<igraph_vector_size(&vec); j++) {
@@ -215,7 +225,7 @@ int igraph_adjlist_init_complementer(const igraph_t *graph,
 	seen[ (long int) VECTOR(vec)[j] ] = 1;
       }
     }
-    IGRAPH_CHECK(igraph_vector_init(&al->adjs[i], n));
+    IGRAPH_CHECK(igraph_vector_int_init(&al->adjs[i], n));
     for (j=0, k=0; k<n; j++) {
       if (!seen[j]) {
 	VECTOR(al->adjs[i])[k++] = j;
@@ -242,11 +252,26 @@ int igraph_adjlist_init_complementer(const igraph_t *graph,
 void igraph_adjlist_destroy(igraph_adjlist_t *al) {
   long int i;
   for (i=0; i<al->length; i++) {
-    if (&al->adjs[i]) { igraph_vector_destroy(&al->adjs[i]); }
+    if (&al->adjs[i]) { igraph_vector_int_destroy(&al->adjs[i]); }
   }
   igraph_Free(al->adjs);
 }
 
+/**
+ * \function igraph_adjlist_clear
+ * Removes all edges from an adjacency list.
+ *
+ * \param al The adjacency list.
+ * Time complexity: depends on memory management, typically O(n), where n is
+ * the total number of elements in the adjacency list.
+ */
+void igraph_adjlist_clear(igraph_adjlist_t *al) {
+  long int i;
+  for (i=0; i<al->length; i++) {
+    igraph_vector_int_clear(&al->adjs[i]);
+  }
+}
+
 /**
  * \function igraph_adjlist_size
  * Number of vertices in an adjacency list.
@@ -261,7 +286,7 @@ igraph_integer_t igraph_adjlist_size(const igraph_adjlist_t *al) {
   return al->length;
 }
 
-/* igraph_vector_t *igraph_adjlist_get(igraph_adjlist_t *al, igraph_integer_t no) { */
+/* igraph_vector_int_t *igraph_adjlist_get(igraph_adjlist_t *al, igraph_integer_t no) { */
 /*   return &al->adjs[(long int)no]; */
 /* } */
 
@@ -279,7 +304,7 @@ igraph_integer_t igraph_adjlist_size(const igraph_adjlist_t *al) {
 void igraph_adjlist_sort(igraph_adjlist_t *al) {
   long int i;
   for (i=0; i<al->length; i++)
-    igraph_vector_sort(&al->adjs[i]);
+    igraph_vector_int_sort(&al->adjs[i]);
 }
 
 /**
@@ -297,26 +322,27 @@ void igraph_adjlist_sort(igraph_adjlist_t *al) {
 int igraph_adjlist_simplify(igraph_adjlist_t *al) {
   long int i;
   long int n=al->length;
-  igraph_vector_t mark;
-  IGRAPH_VECTOR_INIT_FINALLY(&mark, n);
+  igraph_vector_int_t mark;
+  igraph_vector_int_init(&mark, n);
+  IGRAPH_FINALLY(igraph_vector_int_destroy, &mark);
   for (i=0; i<n; i++) {
-    igraph_vector_t *v=&al->adjs[i];
-    long int j, l=igraph_vector_size(v);
+    igraph_vector_int_t *v=&al->adjs[i];
+    long int j, l=igraph_vector_int_size(v);
     VECTOR(mark)[i] = i+1;
     for (j=0; j<l; /* nothing */) {
-      long int e=VECTOR(*v)[j];
+      long int e=(long int) VECTOR(*v)[j];
       if (VECTOR(mark)[e] != i+1) {
 	VECTOR(mark)[e]=i+1;
 	j++;
       } else {
-	VECTOR(*v)[j] = igraph_vector_tail(v);
-	igraph_vector_pop_back(v);
+	VECTOR(*v)[j] = igraph_vector_int_tail(v);
+	igraph_vector_int_pop_back(v);
 	l--;
       }
     }
   }
   
-  igraph_vector_destroy(&mark);
+  igraph_vector_int_destroy(&mark);
   IGRAPH_FINALLY_CLEAN(1);
   return 0;
 }
@@ -325,35 +351,46 @@ int igraph_adjlist_remove_duplicate(const igraph_t *graph,
 				    igraph_adjlist_t *al) {
   long int i;
   long int n=al->length;
+  IGRAPH_UNUSED(graph);
   for (i=0; i<n; i++) {
-    igraph_vector_t *v=&al->adjs[i];
-    long int j, p=1, l=igraph_vector_size(v);
+    igraph_vector_int_t *v=&al->adjs[i];
+    long int j, p=1, l=igraph_vector_int_size(v);
     for (j=1; j<l; j++) {
-      long int e=VECTOR(*v)[j];
+      long int e=(long int) VECTOR(*v)[j];
       /* Non-loop edges, and one end of loop edges are fine. */
       /* We use here, that the vector is sorted and we also keep it sorted */
       if (e != i || VECTOR(*v)[j-1] != e) {
 	VECTOR(*v)[p++] = e;
       }
     }
-    igraph_vector_resize(v, p);
+    igraph_vector_int_resize(v, p);
   }
   
   return 0;
 }
 
 #ifndef USING_R
-int igraph_adjlist_print(const igraph_adjlist_t *al, FILE *outfile) {
+int igraph_adjlist_print(const igraph_adjlist_t *al) {
   long int i;
   long int n=al->length;
   for (i=0; i<n; i++) {
-    igraph_vector_t *v=&al->adjs[i];
-    igraph_vector_print(v);
+    igraph_vector_int_t *v=&al->adjs[i];
+    igraph_vector_int_print(v);
   }
   return 0;
 }
 #endif
 
+int igraph_adjlist_fprint(const igraph_adjlist_t *al, FILE *outfile) {
+  long int i;
+  long int n=al->length;
+  for (i=0; i<n; i++) {
+    igraph_vector_int_t *v=&al->adjs[i];
+    igraph_vector_int_fprint(v, outfile);
+  }
+  return 0;
+}
+
 int igraph_adjedgelist_remove_duplicate(const igraph_t *graph, 
 					igraph_inclist_t *al) {
     IGRAPH_WARNING("igraph_adjedgelist_remove_duplicate() is deprecated, use "
@@ -365,7 +402,7 @@ int igraph_adjedgelist_remove_duplicate(const igraph_t *graph,
 int igraph_adjedgelist_print(const igraph_inclist_t *al, FILE *outfile) {
     IGRAPH_WARNING("igraph_adjedgelist_print() is deprecated, use "
                    "igraph_inclist_print() instead");
-    return igraph_inclist_print(al, outfile);
+    return igraph_inclist_fprint(al, outfile);
 }
 #endif
 
@@ -408,10 +445,10 @@ int igraph_inclist_remove_duplicate(const igraph_t *graph,
   long int i;
   long int n=al->length;
   for (i=0; i<n; i++) {
-    igraph_vector_t *v=&al->incs[i];
-    long int j, p=1, l=igraph_vector_size(v);
+    igraph_vector_int_t *v=&al->incs[i];
+    long int j, p=1, l=igraph_vector_int_size(v);
     for (j=1; j<l; j++) {
-      long int e=VECTOR(*v)[j];
+      long int e=(long int) VECTOR(*v)[j];
       /* Non-loop edges and one end of loop edges are fine. */
       /* We use here, that the vector is sorted and we also keep it sorted */
       if (IGRAPH_FROM(graph, e) != IGRAPH_TO(graph, e) ||
@@ -419,24 +456,34 @@ int igraph_inclist_remove_duplicate(const igraph_t *graph,
 	VECTOR(*v)[p++] = e;
       }
     }
-    igraph_vector_resize(v, p);
+    igraph_vector_int_resize(v, p);
   }
   
   return 0;
 }
 
 #ifndef USING_R
-int igraph_inclist_print(const igraph_inclist_t *al, FILE *outfile) {
+int igraph_inclist_print(const igraph_inclist_t *al) {
   long int i;
   long int n=al->length;
   for (i=0; i<n; i++) {
-    igraph_vector_t *v=&al->incs[i];
-    igraph_vector_print(v);
+    igraph_vector_int_t *v=&al->incs[i];
+    igraph_vector_int_print(v);
   }
   return 0;
 }
 #endif
 
+int igraph_inclist_fprint(const igraph_inclist_t *al, FILE *outfile) {
+  long int i;
+  long int n=al->length;
+  for (i=0; i<n; i++) {
+    igraph_vector_int_t *v=&al->incs[i];
+    igraph_vector_int_fprint(v, outfile);
+  }
+  return 0;
+}
+
 /**
  * \function igraph_inclist_init
  * Initialize an incidence list of edges
@@ -461,28 +508,38 @@ int igraph_inclist_print(const igraph_inclist_t *al, FILE *outfile) {
 int igraph_inclist_init(const igraph_t *graph, 
 			      igraph_inclist_t *il, 
 			      igraph_neimode_t mode) {
-  long int i;
+  igraph_integer_t i;
+  igraph_vector_t tmp;
 
   if (mode != IGRAPH_IN && mode != IGRAPH_OUT && mode != IGRAPH_ALL) {
     IGRAPH_ERROR("Cannot create incidence list view", IGRAPH_EINVMODE);
   }
 
+  igraph_vector_init(&tmp, 0);
+  IGRAPH_FINALLY(igraph_vector_destroy, &tmp);
+
   if (!igraph_is_directed(graph)) { mode=IGRAPH_ALL; }
 
   il->length=igraph_vcount(graph);
-  il->incs=igraph_Calloc(il->length, igraph_vector_t);
+  il->incs=igraph_Calloc(il->length, igraph_vector_int_t);
   if (il->incs == 0) {
     IGRAPH_ERROR("Cannot create incidence list view", IGRAPH_ENOMEM);
   }
 
   IGRAPH_FINALLY(igraph_inclist_destroy, il);  
   for (i=0; i<il->length; i++) {
+    int j, n;
     IGRAPH_ALLOW_INTERRUPTION();
-    IGRAPH_CHECK(igraph_vector_init(&il->incs[i], 0));
-    IGRAPH_CHECK(igraph_incident(graph, &il->incs[i], i, mode));
+    IGRAPH_CHECK(igraph_incident(graph, &tmp, i, mode));
+    n=igraph_vector_size(&tmp);
+    IGRAPH_CHECK(igraph_vector_int_init(&il->incs[i], n));
+    for (j=0; j<n; j++) {
+      VECTOR(il->incs[i])[j] = VECTOR(tmp)[j];
+    }
   }
   
-  IGRAPH_FINALLY_CLEAN(1);
+  igraph_vector_destroy(&tmp);
+  IGRAPH_FINALLY_CLEAN(2);
   return 0;
 }
 
@@ -505,14 +562,14 @@ int igraph_inclist_init_empty(igraph_inclist_t *il, igraph_integer_t n) {
   long int i;
 
   il->length=n;
-  il->incs=igraph_Calloc(il->length, igraph_vector_t);
+  il->incs=igraph_Calloc(il->length, igraph_vector_int_t);
   if (il->incs == 0) {
     IGRAPH_ERROR("Cannot create incidence list view", IGRAPH_ENOMEM);
   }
 
   IGRAPH_FINALLY(igraph_inclist_destroy, il);  
   for (i=0; i<n; i++) {
-    IGRAPH_CHECK(igraph_vector_init(&il->incs[i], 0));
+    IGRAPH_CHECK(igraph_vector_int_init(&il->incs[i], 0));
   }
   
   IGRAPH_FINALLY_CLEAN(1);
@@ -531,13 +588,28 @@ int igraph_inclist_init_empty(igraph_inclist_t *il, igraph_integer_t n) {
 void igraph_inclist_destroy(igraph_inclist_t *il) {
   long int i;
   for (i=0; i<il->length; i++) {
-    /* This works if some igraph_vector_t's are 0, because igraph_vector_destroy can
-       handle this. */
-    igraph_vector_destroy(&il->incs[i]);
+    /* This works if some igraph_vector_int_t's are 0, 
+       because igraph_vector_destroy can handle this. */
+    igraph_vector_int_destroy(&il->incs[i]);
   }
   igraph_Free(il->incs);
 }
 
+/**
+ * \function igraph_inclist_clear
+ * Removes all edges from an incidence list.
+ *
+ * \param il The incidence list.
+ * Time complexity: depends on memory management, typically O(n), where n is
+ * the total number of elements in the incidence list.
+ */
+void igraph_inclist_clear(igraph_inclist_t *il) {
+  long int i;
+  for (i=0; i<il->length; i++) {
+    igraph_vector_int_clear(&il->incs[i]);
+  }
+}
+
 /**
  * \function igraph_lazy_adjlist_init
  * Constructor
@@ -595,6 +667,19 @@ int igraph_lazy_adjlist_init(const igraph_t *graph,
  */
 
 void igraph_lazy_adjlist_destroy(igraph_lazy_adjlist_t *al) {
+  igraph_lazy_adjlist_clear(al);
+  igraph_Free(al->adjs);
+}
+
+/**
+ * \function igraph_lazy_adjlist_clear
+ * Removes all edges from a lazy adjacency list.
+ *
+ * \param al The lazy adjacency list.
+ * Time complexity: depends on memory management, typically O(n), where n is
+ * the total number of elements in the adjacency list.
+ */
+void igraph_lazy_adjlist_clear(igraph_lazy_adjlist_t *al) {
   long int i, n=al->length;
   for (i=0; i<n; i++) {
     if (al->adjs[i] != 0) {
@@ -602,12 +687,11 @@ void igraph_lazy_adjlist_destroy(igraph_lazy_adjlist_t *al) {
       igraph_Free(al->adjs[i]);
     }
   }
-  igraph_Free(al->adjs);
 }
 
 igraph_vector_t *igraph_lazy_adjlist_get_real(igraph_lazy_adjlist_t *al,
 						igraph_integer_t pno) {
-  long int no=pno;
+  igraph_integer_t no=pno;
   int ret;
   if (al->adjs[no] == 0) {
     al->adjs[no] = igraph_Calloc(1, igraph_vector_t);
@@ -737,6 +821,19 @@ int igraph_lazy_inclist_init(const igraph_t *graph,
  */
 
 void igraph_lazy_inclist_destroy(igraph_lazy_inclist_t *il) {
+  igraph_lazy_inclist_clear(il);
+  igraph_Free(il->incs);
+}
+
+/**
+ * \function igraph_lazy_inclist_clear
+ * Removes all edges from a lazy incidence list.
+ *
+ * \param il The lazy incidence list.
+ * Time complexity: depends on memory management, typically O(n), where n is
+ * the total number of elements in the incidence list.
+ */
+void igraph_lazy_inclist_clear(igraph_lazy_inclist_t *il) {
   long int i, n=il->length;
   for (i=0; i<n; i++) {
     if (il->incs[i] != 0) {
@@ -744,12 +841,11 @@ void igraph_lazy_inclist_destroy(igraph_lazy_inclist_t *il) {
       igraph_Free(il->incs[i]);
     }
   }
-  igraph_Free(il->incs);
 }
 
 igraph_vector_t *igraph_lazy_inclist_get_real(igraph_lazy_inclist_t *il,
 						    igraph_integer_t pno) {
-  long int no=pno;
+  igraph_integer_t no=pno;
   int ret;
   if (il->incs[no] == 0) {
     il->incs[no] = igraph_Calloc(1, igraph_vector_t);
